@@ -17,6 +17,9 @@ class Signature:
             description="The user ID to modify",
             pattern=r"^([a-z]+_[a-z]+_\d+|NOT_FOUND)$",
             examples=["sara_doe_496"],
+            json_schema_extra={
+                "available_from": ["find_user_id_by_email", "find_user_id_by_name_zip"]
+            }
         )
         address1: str = Field(default="NOT_FOUND", description="First line of address", examples=["123 Main St"])
         address2: str = Field(default="NOT_FOUND", description="Second line of address", examples=["Apt 1"])
